/**
 * Copyright (C) 2007-2012 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_STDIO_H
#include <stdio.h>
#endif
#ifdef HAVE_MNTENT_H
#include <mntent.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif

#include <gio/gio.h>
#include <glib/gstdio.h>

#include <libxfce4util/libxfce4util.h>

#include "ltop_os_info.h"

#define MNT "/proc/mounts"

/*
 * Public API
 */
LtopOSInfo *
ltop_os_info_get ()
{
    FILE *fp;
    struct mntent *fs;
    gchar *si_dir = NULL;
    gchar **ptr;
    gchar **split;
    gchar *tmp;
    gboolean have_home = FALSE;

    XfceRc *rc;

    GFile *file, *parent, *absolute;
    GFileInfo *file_info;
    const gchar *target;

    LtopOSInfo *info = g_new(LtopOSInfo, 1);
    info->root_device = NULL;
    info->persistence = LTOP_PERSISTENCE_ERROR;

    /* OS version */
    rc = xfce_rc_simple_open ("/etc/lsb-release", TRUE);
    if (G_LIKELY (rc)) {
        info->version = g_strdup (xfce_rc_read_entry (rc, "LINUTOP_CODENAME", ""));
        xfce_rc_close (rc);
    }
    else
    {
        g_free (info);
        return NULL;
    }

    /* get root device and persistence */
    fp = setmntent (MNT, "r");
    if (!fp)
        return info;

    while ((fs = getmntent (fp)) != NULL)
    {
        if (strcmp (fs->mnt_dir, "/") == 0)
        {
            split = g_strsplit (fs->mnt_opts, ",", 0);
            for (ptr=split; *ptr; ptr++)
            {
                if (strncmp (*ptr, "si=", 3) == 0)
                {
                    si_dir = g_strconcat ("/sys/fs/aufs/si_", (*ptr)+3, NULL);
                    break;
                }
            }
            g_strfreev (split);
        }
        else if (strcmp (fs->mnt_dir, "/home") == 0)
        {
            have_home = TRUE;
        }
        else if (strcmp (fs->mnt_dir, "/initrd/cdrom") == 0)
        {
            if (g_str_has_prefix (fs->mnt_fsname, "/dev/disk/"))
            {
                file = g_file_new_for_path (fs->mnt_fsname);
                file_info = g_file_query_info (file,
                                G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
                                0, NULL, NULL);
                target = g_file_info_get_attribute_byte_string (file_info,
                                G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET);
                parent = g_file_get_parent (file);
                absolute = g_file_resolve_relative_path (parent, target);
                info->root_device = g_file_get_path (absolute);
                info->root_device[8] = '\0';
                g_object_unref (file_info);
                g_object_unref (parent);
                g_object_unref (absolute);
                g_object_unref (file);
            }
            else
            {
                info->root_device = g_strndup (fs->mnt_fsname, 8);
            }
        }
    }
    endmntent (fp);

    tmp = g_build_filename (si_dir, "br2", NULL);
    if (g_access (tmp, R_OK) == 0)
    {
        if (have_home)
            info->persistence = LTOP_PERSISTENCE_HOME;
        else
            info->persistence = LTOP_PERSISTENCE_NONE;
    }
    else
    {
        info->persistence = LTOP_PERSISTENCE_FULL;
    }
    g_free (tmp);

    return info;
}

void
ltop_os_info_free (LtopOSInfo *info)
{
    g_free (info->version);
    info->version = NULL;
    g_free (info->root_device);
    info->root_device = NULL;

    g_free (info);
}
