/* main.c
 * Copyright (C) 2007-2012 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_STRING_H
#include <string.h>
#endif
#ifdef HAVE_STDLIB_H
#include <stdlib.h>
#endif
#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif
#ifdef HAVE_PWD_H
#include <pwd.h>
#endif
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <glib/gprintf.h>
#include <glib/gstdio.h>

#include <libxfce4util/libxfce4util.h>

#include <libxfcegui4.h>

void
version (void)
{
    g_printf ("lstart %s\n", VERSION);
}

void
usage (void)
{
    printf ("Usage: lstart [OPTIONS] CMD\n"
            "Execute CMD with startup notification, and optionaly "
            "under a different user ID\n"
            "\n"
            "OPTIONS can be:\n"
            "   -n:     don't use startup notification\n"
            "   -u uid: run the application with given uid\n"
            "   -h:     show this message\n"
            "   -v:     show version informations\n");
}

int
getint (char *text)
{
    int i = 0;
    int ret;
    ret = sscanf (text, "%d", &i);
    if (ret > 0)
        return i;
    return 0;
}

int
main (int argc, char **argv)
{
    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
    gboolean ret = 1;

    int oc;
    int uid = 0;
    struct passwd *pw;
    gboolean use_sn = TRUE;

    while ((oc = getopt (argc, argv, "nu:vh")) != -1)
        switch (oc) {
        case 'h':
            usage ();
            exit (0);
            break;
        case 'v':
            version ();
            exit (0);
            break;
        case 'u':
            uid = getint (optarg);
            break;
        case 'n':
            use_sn = FALSE;
            break;
        }

    if (optind >= argc)
    {
        usage ();
        exit (1);
    }

    gtk_init (&argc, &argv);

    if (strcmp (argv[optind], "") != 0) {
        if ( (getuid () == 0) && (uid > 0)) {
            pw = getpwuid (uid);
            setenv ("HOME", pw->pw_dir, 1);
            setuid (uid);
            seteuid (uid);
        }
        ret = xfce_exec (argv[optind], FALSE, use_sn, NULL);
    }

    exit (ret);
}
