/**
 * Copyright (C) 2007-2012 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "data.h"

/*
 * Lists inspired from the services-admin tool (gnome-system-tools)
 * This matches the default linutop installation, it will probably not be
 * accurate on other systems.
 */
const struct ServiceDescription descriptions[] = {
    { "ANTIVIRUS",           "stock_lock",         N_("Antivirus"),                     N_("Analyzes your incoming mail for virus") },
    { "AUTOMOUNTER",         "disks",              N_("Volumes mounter"),               N_("Mounts your volumes automatically") },
    { "COMMAND_SCHEDULER",   "stock_alarm",        N_("Actions scheduler"),             N_("Executes scheduled actions") },
    { "DATABASE_SERVER",     "file-manager",       N_("Database server"),               N_("Data storage system") },
    { "DISPLAY_MANAGER",     "gdm",                N_("Graphical login manager"),       N_("Allows users to login graphically") },
    { "FILE_SERVER",         "gnome-fs-share",     N_("Folder sharing service"),        N_("Shares folders over your network") },
    { "FILE_SHARING",        "gnome-ftp",          N_("File sharing service"),          N_("Shares files over the Internet") },
    { "FTP_SERVER",          "gnome-ftp",          N_("FTP service"),                   N_("Shares files over the Internet") },
    { "MAIL_FETCHER",        "stock_mail-receive", N_("Mail fetcher"),                  N_("Downloads your mail from remote accounts") },
    { "MTA",                 "stock_mail-send",    N_("Mail agent"),                    N_("Delivers your outgoing mail") },
    { "NETWORK",             "network",            N_(""),                              N_("") },
    { "NTP_SERVER",          "clock",              N_("Clock synchronization service"), N_("Synchronizes your computer clock with Internet time servers") },
    { "PRINTER_SERVICE",     "gnome-dev-printer",  N_("Printer service"),               N_("Allows applications to use printers") },
    { "SECURE_SHELL_SERVER", "gnome-terminal",     N_("Remote shell server"),           N_("Secure shell server") },
    { "SYSTEM_LOGGER",       "logviewer",          N_("Computer activity logger"),      N_("Keeps a log of your computer activity") },
    { "WEB_SERVER",          "apacheconf",         N_("Web server"),                    N_("Shares your web pages over the Internet") },
    { NULL,                  NULL,                 NULL,                                NULL }
};

const struct Service services[] = {
    { "alsa", "SOUND", },
    { "am-utils", "AUTOMOUNTER", },
    { "amavis", "ANTIVIRUS", },
    { "amavis-ng", "ANTIVIRUS", },
    { "apache", "WEB_SERVER", },
    { "apache-perl", "WEB_SERVER", },
    { "apache-ssl", "WEB_SERVER", },
    { "apache2", "WEB_SERVER", },
    { "anacron", "COMMAND_SCHEDULER", },
    { "apmd", "SYSTEM", },
    { "atd", "COMMAND_SCHEDULER", },
    { "atftpd", "FTP_SERVER", },
    { "aumix", "SOUND", },
    { "autofs", "AUTOMOUNTER", },
    { "bind", "NETWORK", },
    { "binfmt-support", "SYSTEM", },
    { "bootlogd", "SYSTEM", },
    { "chargen", "NETWORK", },
    { "chargen-udp", "NETWORK", },
    { "cherokee", "WEB_SERVER", },
    { "clamav-daemon", "ANTIVIRUS", },
    { "courier", "MTA", },
    { "courier-mta", "MTA", },
    { "cpufreqd", "SYSTEM", },
    { "cron", "COMMAND_SCHEDULER", },
    { "crond", "COMMAND_SCHEDULER", },
    { "cupsd", "PRINTER_SERVICE", },
    { "cups", "PRINTER_SERVICE", },
    { "cupsys", "PRINTER_SERVICE", },
    { "daytime", "NETWORK", },
    { "daytime-udp", "NETWORK", },
    { "dbus-1", "SYSTEM", },
    { "ddclient", "DYNAMIC_DNS", },
    { "dhis-client", "DYNAMIC_DNS", },
    { "dictd", "DICT", },
    { "echo", "NETWORK", },
    { "echo-udp", "NETWORK", },
    { "esound", "SOUND", },
    { "exim", "MTA", },
    { "fam", "SYSTEM", },
    { "fcron", "COMMAND_SCHEDULER", },
    { "firstboot", "SYSTEM", },
    { "festival", "SOUND", },
    { "fetchmail", "MAIL_FETCHER", },
    { "freenet6", "NETWORK", },
    { "ftpd", "FTP_SERVER", },
    { "gdm", "DISPLAY_MANAGER", },
    { "gpm", "SYSTEM", },
    { "hdparm", "SYSTEM", },
    { "hotplug", "SYSTEM", },
    { "httpd", "WEB_SERVER", },
    { "inetd", "NETWORK", },
    { "iptables", "NETWORK", },
    { "irda", "SYSTEM", },
    { "isakmpd", "NETWORK", },
    { "isdn", "NETWORK", },
    { "joystick", "SYSTEM", },
    { "kdm"  , "DISPLAY_MANAGER", },
    { "keytable", "SYSTEM", },
    { "klogd", "SYSTEM_LOGGER", },
    { "kudzu", "SYSTEM", },
    { "lircd", "SYSTEM", },
    { "lircmd", "SYSTEM", },
    { "local", "SYSTEM", },
    { "lpd", "PRINTER_SERVICE", },
    { "lpdng", "PRINTER_SERVICE", },
    { "mailscanner", "ANTIVIRUS", },
    { "makedev", "SYSTEM", },
    { "metalog", "SYSTEM_LOGGER", },
    { "mldonkey-server", "FILE_SHARING", },
    { "modules", "SYSTEM", },
    { "module-init-tools", "SYSTEM", },
    { "mysql", "DATABASE_SERVER", },
    { "muddleftpd", "FTP_SERVER", },
    { "named", "NETWORK", },
    { "netfs", "SYSTEM", },
    { "network", "SYSTEM", },
    { "nfs"  , "FILE_SERVER", },
    { "nfs-user-server"  , "FILE_SERVER", },
    { "nfs-kernel-server", "FILE_SERVER", },
    { "nfslock", "SYSTEM", },
    { "nscd", "NETWORK", },
    { "ntpd", "NTP_SERVER", },
    { "ntpdate", "NTP_SERVER", },
    { "ntp-client", "NTP_CLIENT", },
    { "ntp-simple", "NTP_SERVER", },
    { "oftpd", "FTP_SERVER", },
    { "oops", "NETWORK", },
    { "pcmcia", "SYSTEM", },
    { "pdnsd", "NETWORK", },
    { "pipsecd", "NETWORK", },
    { "portmap", "NETWORK", },
    { "postfix", "MTA", },
    { "postgresql", "DATABASE_SERVER", },
    { "postgresql-7.4", "DATABASE_SERVER", },
    { "postgresql-8.0", "DATABASE_SERVER", },
    { "ppp"  , "NETWORK", },
    { "proftpd", "FTP_SERVER", },
    { "privoxy", "NETWORK", },
    { "pure-ftpd", "FTP_SERVER", },
    { "qmail", "MTA", },
    { "random", "SYSTEM", },
    { "rawdevices", "SYSTEM", },
    { "rhnsd", "SYSTEM", },
    { "rsync", "NETWORK", },
    { "rsyncd", "NETWORK", },
    { "rsyslog", "SYSTEM_LOGGER", },
    { "saslauthd", "SYSTEM", },
    { "sendmail", "MTA", },
    { "servers", "NETWORK", },
    { "services", "NETWORK", },
    { "setserial", "SYSTEM", },
    { "sgi_fam", "SYSTEM", },
    { "smartmontools", "SYSTEM", },
    { "smbd", "FILE_SERVER", },
    { "spamassassin", "SYSTEM", },
    { "snmpd", "NETWORK", },
    { "ssh"  , "SECURE_SHELL_SERVER", },
    { "sshd", "SECURE_SHELL_SERVER", },
    { "tftpd-hpa", "FTP_SERVER", },
    { "time", "NETWORK", },
    { "time-udp", "NETWORK", },
    { "urandom", "SYSTEM", },
    { "vcron", "COMMAND_SCHEDULER", },
    { "vmware", "SYSTEM", },
    { "vsftpd", "FTP_SERVER", },
    { "wdm"  , "DISPLAY_MANAGER", },
    { "webmin", "SYSTEM", },
    { "winbind", "NETWORK", },
    { "wine", "SYSTEM", },
    { "wu-ftpd", "FTP_SERVER", },
    { "wzdftpd", "FTP_SERVER", },
    { "xdm", "DISPLAY_MANAGER", },
    { "xfs", "SYSTEM", },
    { "xinetd", "NETWORK", },
    { "zmailer", "MTA", },
    { NULL, NULL },
};

gchar *hidden_services[] = {
    ".depend.boot",
    ".depend.start",
    ".depend.stop",
    ".legacy-bootordering",
    "alsa-utils",
    "acpid",
    "acpi-support",
    "bootclean",
    "bootlogd",
    "bootmisc.sh",
    "checkfs.sh",
    "checkroot.sh",
    "console-screen.sh",
    "console-setup",
    "dbus",
    "dmesg",
    "dns-clean",
    "eeerd",
    "failsafe-x",
    "gdm", /* noX handled by lconfeditor */
    "glibc.sh",
    "hal",
    "halt",
    "hostname",
    "hostname.sh",
    "hwclock",
    "hwclock-save",
    "hwclockfirst.sh",
    "hwclock.sh",
    "keyboard-setup",
    "killprocs",
    "linutop",
    "linutopd",
    "loopback",
    "lrd",
    "module-init-tools",
    "mountall-bootclean.sh",
    "mountall.sh",
    "mountdevsubfs.sh",
    "mountkernfs.sh",
    "mountnfs-bootclean.sh",
    "mountoverflowtmp",
    "mtab-aufs.sh",
    "mtab.sh",
    "network-interface",
    "network-interface-security",
    "network-manager", /* handled by lconfeditor */
    "networking",
    "nmbd",
    "ondemand",
    "pcmciautils",
    "plymouth",
    "plymouth-log",
    "plymouth-splash",
    "plymouth-stop",
    "policykit",
    "pppd-dns",
    "procps",
    "pulseaudio",
    "rc",
    "rc.local",
    "rcS",
    "README",
    "reboot",
    "rmnologin",
    "sendsigs",
    "single",
    "skeleton",
    "splashy",
    "stop-bootlogd",
    "stop-bootlogd-single",
    "udev",
    "udevmonitor",
    "udevtrigger",
    "udev-finish",
    "umountfs",
    "umountnfs.sh",
    "umountroot",
    "urandom",
    "waitnfs.sh",
    "wpa-ifupdown",
    "x11-common",
    "xserver-xorg-input-wacom"
};

