/**
 * Copyright (C) 2007-2012 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif

#include <gtk/gtk.h>

#include <libxfce4util/libxfce4util.h>

#include <services.h>

#include <libxfcegui4.h>

#include "main.h"
#include "helpers.h"
#include "data.h"

enum {
    COL_ACTIVE = 0,
    COL_DESC,
    COL_IMAGE,
    COL_SCRIPT,
    COL_LAST
};

/*
 * Callbacks
 */
static void
on_service_toggled (GtkCellRendererToggle *cell_renderer,
                    gchar *path,
                    gpointer user_data)
{
    Admin *admin;
    GtkTreeModel *model;
    GtkTreeIter iter;
    gboolean active;
    gchar *script;

    admin = (Admin *)user_data;
    model = gtk_tree_view_get_model (GTK_TREE_VIEW (admin->treeview));
    gtk_tree_model_get_iter_from_string (model, &iter, path);

    gtk_tree_model_get (model, &iter,
                        COL_ACTIVE, &active,
                        COL_SCRIPT, &script,
                        -1);
    gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                        COL_ACTIVE, !active,
                        -1);
    if (active)
        admin->blacklist = services_blacklist_add (admin->blacklist, script, TRUE);
    else
        admin->blacklist = services_blacklist_del (admin->blacklist, script, TRUE);
}


static void
build_treeview (Admin *admin)
{
    GtkCellRenderer *renderer;
    GtkTreeViewColumn *column;

    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (admin->treeview), FALSE);

    column = gtk_tree_view_column_new ();

    /* Checkbox */
    renderer = gtk_cell_renderer_toggle_new ();
    g_object_set (G_OBJECT (renderer), "xpad", 12, NULL);
    g_signal_connect (G_OBJECT (renderer), "toggled",
              G_CALLBACK (on_service_toggled), admin);

    gtk_tree_view_insert_column_with_attributes (
        GTK_TREE_VIEW (admin->treeview),
        -1, "", renderer,
        "active", COL_ACTIVE,
        NULL);

    /* Image */
    renderer = gtk_cell_renderer_pixbuf_new ();
    gtk_tree_view_column_pack_start (column, renderer, FALSE);
    gtk_tree_view_column_set_attributes (column, renderer,
        "pixbuf", COL_IMAGE,
        NULL);

    /* Text */
    renderer = gtk_cell_renderer_text_new ();
    gtk_tree_view_column_pack_start (column, renderer, TRUE);
    gtk_tree_view_column_set_attributes (column, renderer,
        "markup", COL_DESC,
        NULL);

    g_object_set (G_OBJECT (renderer), "yalign", 0, NULL);
    gtk_tree_view_insert_column (GTK_TREE_VIEW (admin->treeview), column, -1);

    gtk_tree_view_column_set_sort_column_id (column, 1);
    gtk_tree_view_column_clicked (column);
}

static void
add_item_to_store (gpointer data, gpointer user_data)
{
    gchar *script;
    Admin *admin;
    GtkTreeIter iter;
    const gchar *role = NULL;
    GdkPixbuf *pxb = NULL;
    gchar *desc = NULL;
    gboolean active;
    GtkTreeModel *model;
    int i;

    admin = (Admin *) user_data;
    script = (gchar *) data;
    model = gtk_tree_view_get_model (GTK_TREE_VIEW (admin->treeview));

    i = -1;
    while (services[++i].service)
    {
        if (strcmp (services[i].service, script) != 0)
            continue;
        role = services[i].role;
        break;
    }

    if (role)
    {
        i = -1;
        while (descriptions[++i].role)
        {
            if (! strcmp (descriptions[i].role, role))
            {
                pxb = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
                                                descriptions[i].icon, 48, 0, NULL);
                desc = g_strdup_printf (
                    "<span weight=\"bold\" size=\"larger\">%s (<i>%s</i>)</span>\n%s",
                    _(descriptions[i].description),
                    script,
                    _(descriptions[i].long_description));

                break;
            }
        }
    }
    if (! desc)
    {
        desc = g_strdup (script);
    }

    active = ! services_is_blacklisted (admin->blacklist, script);

    gtk_list_store_append (GTK_LIST_STORE (model), &iter);
    gtk_list_store_set (GTK_LIST_STORE (model), &iter,
        COL_ACTIVE, active,
        COL_DESC, desc,
        COL_IMAGE, pxb,
        COL_SCRIPT, g_strdup (script),
        -1);
}

int
main (int argc, gchar **argv)
{
    GtkWidget *dialog;
    GtkWidget *scw;
    GtkWidget *label;
    GtkListStore *model;
    GtkWidget *d;
    Admin *admin;

    admin = g_new0(Admin, 1);
    admin->scripts = get_scripts_list ();
    admin->blacklist = services_blacklist_list ();

    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
    gtk_init (&argc, &argv);

    if (getuid () != 0) {
        d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                GTK_MESSAGE_WARNING,
                                GTK_BUTTONS_OK,
                                _("You don't appear to be root. Exiting."));
        gtk_dialog_run (GTK_DIALOG (d));
        return 1;
    }

    dialog = gtk_dialog_new_with_buttons (
        _("Services settings"),
        NULL,
        GTK_DIALOG_MODAL,
        GTK_STOCK_QUIT, GTK_RESPONSE_OK,
        NULL);
    gtk_window_set_default_size (GTK_WINDOW (dialog), 480, 400);
    gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
                                   DATADIR "/pixmaps/services-admin.png",
                                   NULL);

    gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
    gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);

    label = gtk_label_new (_("Select the services that you wish to activate:"));
    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), label, FALSE, FALSE, 0);

    scw = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scw),
                                    GTK_POLICY_AUTOMATIC,
                                    GTK_POLICY_AUTOMATIC);
    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), scw, TRUE, TRUE, 0);

    model = gtk_list_store_new (COL_LAST,
                                G_TYPE_BOOLEAN,
                                G_TYPE_STRING,
                                GDK_TYPE_PIXBUF,
                                G_TYPE_POINTER);
    admin->treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    build_treeview (admin);
    g_list_foreach (admin->scripts, add_item_to_store, admin);

    gtk_container_add (GTK_CONTAINER (scw), GTK_WIDGET (admin->treeview));
    gtk_widget_show_all (GTK_DIALOG (dialog)->vbox);

    gtk_dialog_run (GTK_DIALOG (dialog));

    gtk_widget_destroy (dialog);

    /* let the system free everything */

    return 0;
}
